@@ -6,14 +6,11 @@ OC.L10N.register(
     "Rename" : "Adı dəyiş",
     "Send email" : "Email yolla",
     "Delete" : "Sil",
-    "Download" : "Yüklə",
     "Copy link" : "linki nüsxələ",
+    "Download" : "Yüklə",
     "can edit" : "dəyişmək olar",
     "Add" : "Əlavə etmək",
-    "Password protection" : "Password protection",
     "Save" : "Saxla",
-    "Description" : "Açıqlanma",
-    "Settings" : "Settings",
     "Cancel" : "Dayandır",
     "Invalid image" : "Yalnış şəkil",
     "Name" : "Ad",
@@ -45,6 +42,9 @@ OC.L10N.register(
     "Phone" : "Telefon",
     "Mobile" : "Mobil",
     "Fax" : "Faks",
-    "Pager" : "Peycer"
+    "Pager" : "Peycer",
+    "Password protection" : "Password protection",
+    "Description" : "Açıqlanma",
+    "Settings" : "Settings"
 },
 "nplurals=2; plural=(n != 1);");
