@@ -5,40 +5,33 @@ OC.L10N.register(
     "All contacts" : "Todos los contactos",
     "Contacts" : "Contactos",
     "Loading contacts …" : "Cargando contactos ...",
-    "Delete circle" : "Borrar círculo",
-    "Download" : "Descargar",
-    "Send email" : "Enviar correo electrónico",
-    "Groups" : "Grupos",
-    "Group name" : "Nombre del grupo",
-    "Circles" : "Círculos",
-    "Create a new circle" : "Crear un nuevo círculo",
+    "General settings" : "Configuraciones generales",
     "Rename" : "Renombrar",
-    "Enabled" : "Habilitado",
+    "Send email" : "Enviar correo electrónico",
     "Delete" : "Borrar",
     "Copy link" : "Copiar liga",
+    "Download" : "Descargar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
+    "Add" : "Agregar",
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
     "Last modified" : "Última modificación",
-    "Password protection" : "Protección con contraseña",
     "Save" : "Guardar",
-    "Description" : "Descripción",
+    "Cancel" : "Cancelar",
     "Invalid image" : "Imagen inválida",
+    "Address book" : "Libreta de direcciones",
     "Name" : "Nombre",
     "Title" : "Título",
-    "Cancel" : "Cancelar",
-    "Address book" : "Libreta de direcciones",
-    "New contact" : "Nuevo contacto",
     "Search contacts …" : "Buscar contactos ...",
     "No results" : "No hay resultados",
-    "Personal circle" : "Círculo personal",
     "Pending" : "Pendiente",
+    "None" : "Ninguno",
+    "New contact" : "Nuevo contacto",
     "Close" : "Cerrar",
     "Import" : "Importar",
     "Not grouped" : "No agrupado",
-    "Circle" : "Círculo",
     "User" : "Usuario",
     "Group" : "Grupo",
     "Email" : "Correo electrónico",
@@ -47,12 +40,12 @@ OC.L10N.register(
     "Moderator" : "Moderador",
     "Admin" : "Administración",
     "Owner" : "Dueño",
-    "Users" : "Usuarios",
-    "Nickname" : "Apodo",
+    "Privacy" : "Privacidad",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
     "Prefix" : "Prefijo",
     "Suffix" : "Sufijo",
+    "Nickname" : "Apodo",
     "Notes" : "Notas",
     "Website" : "Sitio web",
     "Location" : "Ubicación",
@@ -91,12 +84,12 @@ OC.L10N.register(
     "Relative" : "Familiar",
     "Friend" : "Amigo",
     "Colleague" : "Colega",
-    "Manager" : "Gerente",
     "Assistant" : "Asistente",
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "None" : "Ninguno",
-    "Unknown" : "Desconocido"
+    "Unknown" : "Desconocido",
+    "Password protection" : "Protección con contraseña",
+    "Description" : "Descripción"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
