@@ -9,8 +9,8 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Send email" : "Enviar correo electrónico",
     "Delete" : "Borrar",
-    "Download" : "Descargar",
     "Copy link" : "Copiar liga",
+    "Download" : "Descargar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
     "Add" : "Agregar",
@@ -18,14 +18,12 @@ OC.L10N.register(
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
     "Last modified" : "Última modificación",
-    "Password protection" : "Protección con contraseña",
     "Save" : "Guardar",
-    "Description" : "Descripción",
     "Cancel" : "Cancelar",
     "Invalid image" : "Imagen inválida",
+    "Address book" : "Libreta de direcciones",
     "Name" : "Nombre",
     "Title" : "Título",
-    "Address book" : "Libreta de direcciones",
     "Search contacts …" : "Buscar contactos ...",
     "No results" : "No hay resultados",
     "Pending" : "Pendiente",
@@ -42,6 +40,7 @@ OC.L10N.register(
     "Moderator" : "Moderador",
     "Admin" : "Admin",
     "Owner" : "Dueño",
+    "Privacy" : "Privacidad",
     "Groups" : "Grupos",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
@@ -94,6 +93,7 @@ OC.L10N.register(
     "Female" : "Femenino",
     "Male" : "Masculino",
     "Unknown" : "Desconocido",
-    "Manager" : "Gerente"
+    "Password protection" : "Protección con contraseña",
+    "Description" : "Descripción"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
