@@ -18,9 +18,7 @@ OC.L10N.register(
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
     "Last modified" : "Última modificación",
-    "Password protection" : "Protección con contraseña",
     "Save" : "Guardar",
-    "Description" : "Descripción",
     "Cancel" : "Cancelar",
     "Invalid image" : "Imagen inválida",
     "Address book" : "Libreta de direcciones",
@@ -42,6 +40,7 @@ OC.L10N.register(
     "Moderator" : "Moderador",
     "Admin" : "Administración",
     "Owner" : "Dueño",
+    "Privacy" : "Privacidad",
     "Groups" : "Grupos",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
@@ -90,6 +89,8 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "Unknown" : "Desconocido"
+    "Unknown" : "Desconocido",
+    "Password protection" : "Protección con contraseña",
+    "Description" : "Descripción"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
