@@ -5,22 +5,20 @@ OC.L10N.register(
     "All contacts" : "Semua kontak",
     "Contacts" : "Kontak",
     "A contacts app for Nextcloud" : "Sebuah aplikasi kontak untuk Nextcloud",
-    "Send email" : "Kirim surel",
-    "Download" : "Unduh",
     "Rename" : "Ubah nama",
+    "Send email" : "Kirim email",
     "Delete" : "Hapus",
     "Copy link" : "Salin tautan",
+    "Download" : "Unduh",
     "Share with users or groups" : "Bagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
     "can edit" : "dapat menyunting",
+    "Add" : "Masukkan",
     "First name" : "Nama depan",
     "Last name" : "Nama belakang",
     "Display name" : "Nama tampilan",
     "Last modified" : "Terakhir diubah",
-    "Password protection" : "Password protection",
     "Save" : "Simpan",
-    "Description" : "Deskrisi",
-    "Settings" : "Settings",
     "Cancel" : "Membatalkan",
     "Invalid image" : "Gambar tidak sah",
     "Name" : "Nama",
@@ -35,10 +33,10 @@ OC.L10N.register(
     "Not grouped" : "Tidak dikelompokkan",
     "User" : "Pengguna",
     "Group" : "Grup",
-    "Email" : "Surel",
+    "Email" : "Email",
     "Admin" : "Admin",
     "Owner" : "Owner",
-    "Users" : "Pengguna",
+    "Privacy" : "Privasi",
     "Detailed name" : "Nama lengkap",
     "Additional names" : "Nama tambahan",
     "Prefix" : "Prefix",
@@ -69,6 +67,9 @@ OC.L10N.register(
     "Pager" : "Pager",
     "Voice" : "Suara",
     "Social network" : "Media sosial",
-    "Unknown" : "Tidak diketahui"
+    "Unknown" : "Tidak diketahui",
+    "Password protection" : "Password protection",
+    "Description" : "Deskrisi",
+    "Settings" : "Settings"
 },
 "nplurals=1; plural=0;");
