@@ -9,8 +9,8 @@ OC.L10N.register(
     "Rename" : "სახელის შეცვლა",
     "Send email" : "ელ-წერილის გაგზავნა",
     "Delete" : "გაუქმება",
-    "Download" : "ჩამოტვირთვა",
     "Copy link" : "ბმულის კოპირება",
+    "Download" : "ჩამოტვირთვა",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
     "can edit" : "შეუძლია შეცვლა",
     "Add" : "დამატება",
@@ -18,15 +18,12 @@ OC.L10N.register(
     "Last name" : "გვარი",
     "Display name" : "დისპლეი სახელი",
     "Last modified" : "ბოლო ცვლილება",
-    "Password protection" : "პაროლით თავდაცვა",
     "Save" : "შენახვა",
-    "Description" : "აღწერილობა",
-    "Settings" : "Settings",
     "Cancel" : "უარყოფა",
     "Invalid image" : "არასწორი სურათი",
+    "Address book" : "მისამართების წიგნი",
     "Name" : "სახელი",
     "Title" : "სათაური",
-    "Address book" : "მისამართების წიგნი",
     "Search contacts …" : "მოძებნეთ კონტაქტები ...",
     "No results" : "შედეგები არაა",
     "Pending" : "მოლოდინში",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Moderator" : "მოდერატორი",
     "Admin" : "ადმინისტრატორი",
     "Owner" : "მფლობელი",
+    "Privacy" : "კონფიდენციალურობა",
     "Detailed name" : "დეტალური სახელი",
     "Additional names" : "დამატებითი სახელები",
     "Prefix" : "პრეფიქსი",
@@ -75,7 +73,6 @@ OC.L10N.register(
     "Voice" : "ხმა",
     "Car" : "მაქნანა",
     "Work pager" : "სამუშაო პეიჯერი",
-    "Manager" : "მენეჯერი",
     "Social network" : "სოციალური ქსელი",
     "Spouse" : "მეუღლე",
     "Child" : "შვილი",
@@ -91,6 +88,9 @@ OC.L10N.register(
     "Gender" : "სქესი",
     "Female" : "მდედორობითი",
     "Male" : "მამრობითი",
-    "Unknown" : "ამოუცნობი"
+    "Unknown" : "ამოუცნობი",
+    "Password protection" : "პაროლით თავდაცვა",
+    "Description" : "აღწერილობა",
+    "Settings" : "Settings"
 },
 "nplurals=2; plural=(n!=1);");
