@@ -3,15 +3,13 @@ OC.L10N.register(
     {
     "Details" : "ព័ត៌មាន​លម្អិត",
     "Contacts" : "ទំនាក់​ទំនង",
-    "Send email" : "ផ្ញើ​អ៊ីមែល",
-    "Download" : "ទាញយក",
     "Rename" : "ប្ដូរ​ឈ្មោះ",
+    "Send email" : "ផ្ញើ​អ៊ីមែល",
     "Delete" : "លុប",
+    "Download" : "ទាញយក",
     "can edit" : "អាច​កែប្រែ",
-    "Password protection" : "Password protection",
+    "Add" : "បញ្ចូល",
     "Save" : "រក្សាទុក",
-    "Description" : "ការ​អធិប្បាយ",
-    "Settings" : "Settings",
     "Cancel" : "បោះបង់",
     "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
     "Name" : "ឈ្មោះ",
@@ -27,12 +25,14 @@ OC.L10N.register(
     "Email" : "អ៊ីមែល",
     "Admin" : "អ្នក​គ្រប់​គ្រង",
     "Owner" : "Owner",
-    "Users" : "អ្នកប្រើ",
     "Notes" : "កំណត់​ចំណាំ",
     "Location" : "ទីតាំង",
     "Work" : "ធ្វើការ",
     "Other" : "ផ្សេងៗ",
     "Address" : "អាសយដ្ឋាន",
-    "Birthday" : "ថ្ងៃ​កំណើត"
+    "Birthday" : "ថ្ងៃ​កំណើត",
+    "Password protection" : "Password protection",
+    "Description" : "ការ​អធិប្បាយ",
+    "Settings" : "Settings"
 },
 "nplurals=1; plural=0;");
