@@ -1,14 +1,13 @@
 OC.L10N.register(
     "contacts",
     {
-    "Send email" : "ಇ-ಅಂಚೆಯನ್ನು  ಕಳುಹಿಸಿ",
-    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
     "Rename" : "﻿ಮರುಹೆಸರಿಸು",
+    "Send email" : "ಇ-ಅಂಚೆಯನ್ನು  ಕಳುಹಿಸಿ",
     "Delete" : "﻿ಅಳಿಸಿ",
+    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
     "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
-    "Password protection" : "Password protection",
+    "Add" : "﻿ಸೇರಿಸಿ",
     "Save" : "﻿ಉಳಿಸಿ",
-    "Settings" : "Settings",
     "Cancel" : "﻿ರದ್ದು",
     "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
     "Name" : "﻿ಹೆಸರು",
@@ -22,10 +21,11 @@ OC.L10N.register(
     "Email" : "﻿ಇ-ಅಂಚೆ",
     "Admin" : "﻿ನಿರ್ವಹಕ",
     "Owner" : "Owner",
-    "Users" : "﻿ಬಳಕೆದಾರರು",
     "Notes" : "Notes",
     "Home" : "﻿ಮುಖಪುಟ",
     "Other" : "﻿ಇತರೆ",
-    "Address" : "ವಿಳಾಸ"
+    "Address" : "ವಿಳಾಸ",
+    "Password protection" : "Password protection",
+    "Settings" : "Settings"
 },
 "nplurals=2; plural=(n > 1);");
