@@ -3,18 +3,17 @@ OC.L10N.register(
     {
     "Details" : "Detailer",
     "Contacts" : "Kontakter",
-    "Download" : "Eroflueden",
+    "Loading …" : "Loading …",
     "Rename" : "Ëmbenennen",
     "Delete" : "Läschen",
     "Copy link" : "Link kopéieren",
+    "Download" : "Eroflueden",
     "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
     "can edit" : "kann änneren",
+    "Add" : "Derbäimaachen",
     "First name" : "Virnumm",
     "Last name" : "Famillje Numm",
-    "Password protection" : "Password protection",
     "Save" : "Späicheren",
-    "Description" : "Beschreiwung",
-    "Settings" : "Settings",
     "Cancel" : "Ofbriechen",
     "Invalid image" : "Ongülteg d'Bild",
     "Name" : "Numm",
@@ -28,7 +27,6 @@ OC.L10N.register(
     "Email" : "Email",
     "Admin" : "Admin",
     "Owner" : "Owner",
-    "Users" : "Benotzer",
     "Additional names" : "Weider Nimm",
     "Nickname" : "Spëtznumm",
     "Notes" : "Notizen",
@@ -46,6 +44,9 @@ OC.L10N.register(
     "Pager" : "Pager",
     "Voice" : "Voice",
     "Relative" : "Relativ",
-    "Unknown" : "Onbekannt"
+    "Unknown" : "Onbekannt",
+    "Password protection" : "Password protection",
+    "Description" : "Beschreiwung",
+    "Settings" : "Settings"
 },
 "nplurals=2; plural=(n != 1);");
