@@ -4,11 +4,11 @@ OC.L10N.register(
     "Details" : "ລາຍລະອຽດ",
     "Contacts" : "ຕິດຕໍ່",
     "Loading …" : "ກຳລັງໂຫຼດ",
-    "Download" : "ດາວໂຫລດ",
     "Rename" : "ປ່ຽນຊື່",
     "Delete" : "ລຶບ",
     "Copy link" : "ສຳເນົາລິງ",
-    "Password protection" : "ລະຫັດປ້ອງກັນ",
+    "Download" : "ດາວໂຫລດ",
+    "Add" : "ເພີ່ມ",
     "Save" : "ບັນທຶກ",
     "Cancel" : "ຍົກເລີກ",
     "Invalid image" : "ບໍ່ມີຮູບພາບ",
@@ -24,12 +24,13 @@ OC.L10N.register(
     "Email" : "ອິເມວ",
     "Admin" : "ຜູ້ເບິ່ງເເຍງລະບົບ",
     "Owner" : "ເຈົ້າຂອງ",
-    "Users" : "ຜູ້ໃຊ້",
+    "Privacy" : "ຄວາມເປັນສ່ວນຕົວ",
     "Website" : "ເວັບໄຊ",
     "Home" : "ໜ້າຫຼັກ",
     "Address" : "ທີ່ຢູ່",
     "City" : "ເມືອງ",
     "Country" : "ປະເທດ",
-    "Unknown" : "ບໍ່ຮູ້"
+    "Unknown" : "ບໍ່ຮູ້",
+    "Password protection" : "ລະຫັດປ້ອງກັນ"
 },
 "nplurals=1; plural=0;");
