@@ -8,10 +8,10 @@ OC.L10N.register(
     "Loading …" : "Уншиж байна...",
     "Rename" : "Нэр солих",
     "Delete" : "Устгах",
-    "Download" : "Татаж авах",
     "Copied" : "Хуулагдсан",
     "Cannot copy" : "Хуулагдаагүй",
     "Copy link" : "Холбоос хуулах",
+    "Download" : "Татаж авах",
     "Share with users or groups" : "Бусдад түгээх",
     "can edit" : "засаж чадна",
     "Add" : "нэмэх",
@@ -19,23 +19,21 @@ OC.L10N.register(
     "Last name" : "Овог",
     "Display name" : "Харагдах нэр",
     "Last modified" : "Сүүлд өөрчилсөн",
-    "Password protection" : "Password protection",
     "Save" : "Хадгалах",
-    "Description" : "Тайлбар",
-    "Settings" : "Settings",
     "Cancel" : "болиулах",
+    "Invalid image" : "буруу зураг",
     "Upload a new picture" : "Шинэ зураг оруулах",
     "Choose from Files" : "Файлаас сонгох",
     "Download picture" : "Зураг татаж авах",
     "Delete picture" : "Зураг устгах",
-    "Invalid image" : "буруу зураг",
+    "Address book" : "Хаягийн бүртгэл",
     "Name" : "Нэр",
     "Title" : "Цол/Албан тушаал",
     "Select address book" : "Хаягийн бүртгэл сонгох",
-    "Address book" : "Хаягийн бүртгэл",
     "No results" : "Үр дүн байхгүй",
     "Pending" : "Хүлээгдэж байгаа",
     "None" : "юу ч үгүй",
+    "Add member" : "Гишүүн нэмэх",
     "New contact" : "Шинэ харилцагч",
     "Close" : "Хаах",
     "Import" : "Импорт",
@@ -47,6 +45,7 @@ OC.L10N.register(
     "Moderator" : "Шалгагч",
     "Admin" : "Админ",
     "Owner" : "Эзэмшигч",
+    "Privacy" : "Хувийн нууц",
     "Groups" : "Багууд",
     "Detailed name" : "Дэлгэрэнгүй нэр",
     "Additional names" : "Нэмэлт нэрүүд",
@@ -85,6 +84,8 @@ OC.L10N.register(
     "Male" : "Эрэгтэй",
     "Unknown" : "Үл танигдах зүйл",
     "Time zone" : "Цагийн бүс",
-    "Manager" : "Менежер"
+    "Password protection" : "Password protection",
+    "Description" : "Тайлбар",
+    "Settings" : "Settings"
 },
 "nplurals=2; plural=(n != 1);");
