@@ -3,17 +3,15 @@ OC.L10N.register(
     {
     "Details" : "Detaljar",
     "Contacts" : "Kontaktar",
-    "Download" : "Last ned",
     "Rename" : "Gje nytt namn",
     "Delete" : "Ta bort",
+    "Download" : "Last ned",
     "can edit" : "kan endra",
+    "Add" : "Legg til",
     "First name" : "Fornamn",
     "Last name" : "Etternamn",
     "Last modified" : "Siste endra",
-    "Password protection" : "Password protection",
     "Save" : "Lagre",
-    "Description" : "Skildring",
-    "Settings" : "nstillingar",
     "Cancel" : "Avbryt",
     "Invalid image" : "Ugyldig bilete",
     "Name" : "Namn",
@@ -29,7 +27,6 @@ OC.L10N.register(
     "Moderator" : "Moderator",
     "Admin" : "Administrer",
     "Owner" : "Owner",
-    "Users" : "Brukarare",
     "Additional names" : "Andre namn",
     "Nickname" : "Kallenamn",
     "Notes" : "Notat",
@@ -48,6 +45,9 @@ OC.L10N.register(
     "Fax" : "Faks",
     "Pager" : "Personsøkjar",
     "Voice" : "Tale",
-    "Unknown" : "Ukjend"
+    "Unknown" : "Ukjend",
+    "Password protection" : "Password protection",
+    "Description" : "Skildring",
+    "Settings" : "nstillingar"
 },
 "nplurals=2; plural=(n != 1);");
