@@ -9,9 +9,9 @@ OC.L10N.register(
     "Rename" : "Redenumește",
     "Send email" : "Trimite email-ul",
     "Delete" : "Șterge",
-    "Download" : "Descărcare",
     "Copied" : "Copiat",
     "Copy link" : "Copiază linkul",
+    "Download" : "Descărcare",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
     "can edit" : "poate edita",
@@ -19,16 +19,13 @@ OC.L10N.register(
     "First name" : "Prenume",
     "Last name" : "Nume",
     "Display name" : "Nume afișat",
-    "Password protection" : "Protecție parolă ",
     "Save" : "Salvează",
-    "Description" : "Descriere",
-    "Settings" : "Settings",
     "Cancel" : "Anulează",
     "Invalid image" : "Imagine invalidă",
+    "Address book" : "Listă de contacte",
     "Name" : "Nume",
     "Title" : "Titlu",
     "Company" : "Companie",
-    "Address book" : "Listă de contacte",
     "Search contacts …" : "Caută contacte ...",
     "No results" : "Niciun rezultat",
     "Pending" : "În așteptare",
@@ -47,7 +44,7 @@ OC.L10N.register(
     "Moderator" : "Moderator",
     "Admin" : "Admin",
     "Owner" : "Proprietar",
-    "Visibility" : "Vizibil",
+    "Privacy" : "Confidențialitate",
     "Detailed name" : "Nume detaliat",
     "Additional names" : "Nume adiționale",
     "Prefix" : "Prefix",
@@ -96,6 +93,9 @@ OC.L10N.register(
     "Female" : "Femeie",
     "Male" : "Bărbat",
     "Unknown" : "Necunoscut",
-    "Manager" : "Director"
+    "Password protection" : "Protecție parolă ",
+    "Description" : "Descriere",
+    "Settings" : "Settings",
+    "Visibility" : "Vizibil"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
