@@ -12,9 +12,9 @@ OC.L10N.register(
     "Rename" : "Riemëro",
     "Send email" : "Dërgo email",
     "Delete" : "Fshije",
-    "Download" : "Shkarko",
     "Copied" : "Kopjuar",
     "Copy link" : "Kopjo linkun",
+    "Download" : "Shkarko",
     "Share with users or groups" : "Nda me përdoruesit ose grupet",
     "can edit" : "mund të modifikoni",
     "Add" : "Shto",
@@ -22,34 +22,32 @@ OC.L10N.register(
     "Last name" : "Mbiemër",
     "Display name" : "Shfaq emrin",
     "Last modified" : "Ndryshuar së fundmi",
-    "Password protection" : "Password protection",
     "Save" : "Ruaj",
-    "Description" : "Përshkrim",
     "Cancel" : "Anullo",
-    "Upload a new picture" : "Ngarko një foto të re",
-    "Download picture" : "Shkarko foton",
-    "Delete picture" : "Fshi foton",
     "Invalid image" : "Figurë e pavlefshme",
     "Pick an avatar" : "Zgjidh një avatar",
     "Error while processing the picture." : "Gabim gjatë procesimit të figurës.",
     "Avatar already up to date" : "Avatari është i përditësuar.",
     "Avatar download failed" : "Shkarkimi i avatarit dështoi.",
+    "Upload a new picture" : "Ngarko një foto të re",
+    "Download picture" : "Shkarko foton",
+    "Delete picture" : "Fshi foton",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ky kontakt është në gjendjen vetëm-lexo. Ju nuk keni të drejtë ta ndryshoni këtë kontakt.",
+    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakti që po përpiqeni të përditësoni, ka ndryshuar. Ju lutem rifreskoni manualisht kontaktin. Çdo ndryshim i mëtejshëm nuk do të ruhet.",
+    "Address book" : "Libri i adresave",
+    "Name" : "Emri",
+    "Syntax error. Cannot open the contact." : "Gabim sintakse. Kontakti nuk mund të hapet.",
     "No contact selected" : "Nuk është zgjedhur asnjë kontakt",
     "Select a contact on the list to begin" : "Zgjidh një kontakt nga lista për të filluar",
-    "Name" : "Emri",
     "Title" : "Titulli",
     "Company" : "Kompania",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "Ky kontakt ishte prishur dhe u rregullua. Ju lutem rishikoni përmbajtjen dhe klikoni këtu për ta ruajtur atë.",
     "Generate QR Code" : "Gjeneroni Kodin QR",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ky kontakt është në gjendjen vetëm-lexo. Ju nuk keni të drejtë ta ndryshoni këtë kontakt.",
-    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakti që po përpiqeni të përditësoni, ka ndryshuar. Ju lutem rifreskoni manualisht kontaktin. Çdo ndryshim i mëtejshëm nuk do të ruhet.",
-    "Address book" : "Libri i adresave",
-    "Syntax error. Cannot open the contact." : "Gabim sintakse. Kontakti nuk mund të hapet.",
     "Search contacts …" : "Kërko kontakte ...",
     "No results" : "Asnjë rezultat",
     "Pending" : "Në Pritje të Konfirmimit",
-    "Select type" : "Zgjidhni llojin",
     "Select Date" : "Zgjidhni Datën",
+    "Select type" : "Zgjidhni llojin",
     "Add contact in group" : "Shto kontaktin në grup",
     "None" : "Asnjë",
     "New contact" : "Kontakt i ri",
@@ -64,6 +62,7 @@ OC.L10N.register(
     "Moderator" : "Moderator",
     "Admin" : "Administrator",
     "Owner" : "Zotëruesi",
+    "Privacy" : "Privatësia",
     "Detailed name" : "Emri i hollësishëm",
     "Additional names" : "Emra shtesë",
     "Prefix" : "Parashtesë",
@@ -94,7 +93,6 @@ OC.L10N.register(
     "Pager" : "Faques",
     "Voice" : "Zë",
     "Car" : "Makine",
-    "Manager" : "Manaxher/e",
     "Social network" : "Rrjet social",
     "Spouse" : "Bashkëshort/e",
     "Child" : "Fëmijë",
@@ -113,6 +111,8 @@ OC.L10N.register(
     "Gender" : "Gjinia",
     "Female" : "Femër",
     "Male" : "Mashkull",
-    "Unknown" : "I/E panjohur"
+    "Unknown" : "I/E panjohur",
+    "Password protection" : "Password protection",
+    "Description" : "Përshkrim"
 },
 "nplurals=2; plural=(n != 1);");
