@@ -3,15 +3,13 @@ OC.L10N.register(
     {
     "Details" : "விவரங்கள்",
     "Contacts" : "தொடர்புகள்",
-    "Download" : "பதிவிறக்குக",
     "Rename" : "பெயர்மாற்றம்",
     "Delete" : "நீக்குக",
+    "Download" : "பதிவிறக்குக",
     "can edit" : "தொகுக்க முடியும்",
     "First name" : "முதல் பெயர்",
     "Last name" : "கடைசிப் பெயர்",
-    "Password protection" : "Password protection",
     "Save" : "சேமிக்க ",
-    "Description" : "விவரிப்பு",
     "Cancel" : "இரத்து செய்க",
     "Name" : "பெயர்",
     "Title" : "தலைப்பு",
@@ -24,7 +22,6 @@ OC.L10N.register(
     "Email" : "மின்னஞ்சல்",
     "Admin" : "நிர்வாகம்",
     "Owner" : "Owner",
-    "Users" : "பயனாளர்",
     "Additional names" : "மேலதிக பெயர்கள்",
     "Nickname" : "பட்டப்பெயர்",
     "Notes" : "குறிப்புகள்",
@@ -42,6 +39,8 @@ OC.L10N.register(
     "Fax" : "தொலை நகல்",
     "Pager" : "தொலை அழைப்பான்",
     "Voice" : "குரல்",
-    "Unknown" : "தெரியாத"
+    "Unknown" : "தெரியாத",
+    "Password protection" : "Password protection",
+    "Description" : "விவரிப்பு"
 },
 "nplurals=2; plural=(n != 1);");
