@@ -25,15 +25,15 @@ OC.L10N.register(
     "Rename" : "เปลี่ยนชื่อ",
     "Send email" : "ส่งอีเมล",
     "Delete" : "ลบ",
+    "Show all groups" : "แสดงกลุ่มทั้งหมด",
+    "Collapse groups" : "ย่อกลุ่ม",
     "Contact groups" : "กลุ่มรายชื่อ",
     "Create a new contact group" : "สร้างกลุ่มรายชื่อใหม่",
     "Contact group name" : "ชื่อของกลุ่มรายชื่อ",
-    "Show all groups" : "แสดงกลุ่มทั้งหมด",
-    "Collapse groups" : "ย่อกลุ่ม",
-    "Download" : "ดาวน์โหลด",
     "Copied" : "คัดลอกแล้ว",
     "Cannot copy" : "ไม่สามารถคัดลอก",
     "Copy link" : "คัดลอกลิงก์",
+    "Download" : "ดาวน์โหลด",
     "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
     "can edit" : "สามารถแก้ไข",
     "Add" : "เพิ่ม",
@@ -43,29 +43,26 @@ OC.L10N.register(
     "Last modified" : "แก้ไขล่าสุด",
     "Sort by {sorting}" : "เรียงตาม {sorting}",
     "Manages" : "จัดการ",
-    "Password protection" : "ป้องกันด้วยรหัสผ่าน",
     "Save" : "บันทึก",
-    "Request to join" : "ขอเข้าร่วม",
-    "Description" : "รายละเอียด",
-    "Settings" : "Settings",
+    "Edit" : "แก้ไข",
     "Cancel" : "ยกเลิก",
-    "Upload a new picture" : "อัปโหลดรูปภาพใหม่",
-    "Choose from Files" : "เลือกจากไฟล์",
-    "Get from " : "รับจาก",
-    "Download picture" : "ดาวน์โหลดรูปภาพ",
-    "Delete picture" : "ลบรูปภาพ",
+    "Request to join" : "ขอเข้าร่วม",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
     "Pick an avatar" : "เลือกภาพแทนตัว",
     "Error while processing the picture." : "เกิดข้อผิดพลาดขณะประมวลผลรูปภาพ",
+    "Upload a new picture" : "อัปโหลดรูปภาพใหม่",
+    "Choose from Files" : "เลือกจากไฟล์",
+    "Download picture" : "ดาวน์โหลดรูปภาพ",
+    "Delete picture" : "ลบรูปภาพ",
     "Name" : "ชื่อ",
     "Title" : "ชื่อเรื่อง",
     "Company" : "บริษัท",
-    "Edit" : "แก้ไข",
     "Search contacts …" : "ค้นหารายชื่อผู้ติดต่อ …",
     "No results" : "ไม่มีผลลัพธ์",
     "Pending" : "รอดำเนินการ",
     "None" : "ไม่มี",
     "Select option" : "เลือกตัวเลือก",
+    "Add member" : "เพิ่มสมาชิก",
     "New contact" : "รายชื่อใหม่",
     "Close" : "ปิด",
     "Import" : "นำเข้า",
@@ -107,6 +104,9 @@ OC.L10N.register(
     "Voice" : "เสียงพูด",
     "Social network" : "เครือข่ายโซเชียล",
     "Relative" : "สัมพัทธ์",
-    "Unknown" : "ไม่ทราบ"
+    "Unknown" : "ไม่ทราบ",
+    "Password protection" : "ป้องกันด้วยรหัสผ่าน",
+    "Description" : "รายละเอียด",
+    "Settings" : "Settings"
 },
 "nplurals=1; plural=0;");
