@@ -3,19 +3,23 @@ OC.L10N.register(
     {
     "Contacts" : "Contacts",
     "Loading contacts …" : "Loading contacts …",
-    "Download" : "Download",
-    "Rename" : "Rename",
-    "Delete" : "Delete",
-    "Save" : "Save",
-    "Cancel" : "Cancel",
+    "Rename" : "Nomini o'zgartirish",
+    "Delete" : "O'chirish",
+    "Download" : "Yuklab olish",
+    "Add" : "Qo'shish",
+    "Save" : "Saqlash",
+    "Cancel" : "Bekor qilish",
     "Invalid image" : "Invalid image",
     "Name" : "Name",
     "Search contacts …" : "Search contacts …",
     "Pending" : "Pending",
+    "None" : "Yo'q",
+    "Close" : "Yopish",
     "Member" : "Member",
     "Admin" : "Admin",
     "Users" : "Users",
     "Notes" : "Notes",
-    "Unknown" : "Unknown"
+    "Unknown" : "Unknown",
+    "Settings" : "Sozlamalar"
 },
 "nplurals=1; plural=0;");
