@@ -88,31 +88,26 @@ OC.L10N.register(
     "Sort by {sorting}" : "按 {sorting} 排序",
     "Manages" : "管理",
     "Oversees" : "監督",
-    "An error happened during the config change" : "配置更改期間發生錯誤",
-    "Password protection" : "密碼保護",
     "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
     "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
     "Unique password …" : "獨一無二的密碼 ...",
     "Save" : "保存",
     "Change unique password" : "更改獨一無二的密碼",
     "Failed to save password. Please try again later." : "保存密碼失敗。請稍後再試。",
+    "An error happened during the config change" : "配置更改期間發生錯誤",
     "There is no description for this team" : "此團隊沒有描述",
     "Enter a description for the team" : "輸入團隊的描述",
     "An error happened during description sync" : "描述同步期間發生錯誤",
     "An error happened during name sync" : "名稱同步期間發生錯誤",
-    "Team owned by {owner}" : "{owner} 擁有的團隊",
-    "Team settings" : "團隊設定",
+    "Team name" : "團隊名字",
+    "Team owner" : "團隊所有者",
+    "Edit" : "編輯",
+    "Cancel" : "取消",
     "Request to join" : "請求加入",
-    "Description" : "描述",
     "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
     "You are not a member of {circle}" : "您不是 {circle} 的成員",
-    "Team resources" : "團隊資源",
-    "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
-    "Team name" : "團隊名字",
-    "Settings" : "Settings",
-    "Actions" : "操作",
+    "Members" : "成員",
     "Confirm" : "確認",
-    "Cancel" : "取消",
     "Add more info" : "添加更多資料",
     "More fields" : "更多欄位",
     "Please select a valid format" : "請選擇有效的格式",
@@ -149,7 +144,6 @@ OC.L10N.register(
     "Go to talk conversation" : "前往對話",
     "View profile" : "檢視個人檔案",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
-    "Edit" : "編輯",
     "Clone contact" : "複製聯絡人",
     "Generate QR Code" : "生成 QR Code",
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
@@ -160,8 +154,13 @@ OC.L10N.register(
     "Calendar events with you" : "與您分享的日曆活動",
     "Deck cards with you" : "與您分享的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
+    "_Delete {number} contact_::_Delete {number} contacts_" : ["刪除 {number} 個聯絡人"],
+    "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
+    "Are you sure you want to proceed?" : "您想要繼續嗎？",
     "Search contacts …" : "搜尋聯絡人…",
+    "Unselect {number}" : "取消選取 {number}",
     "Add to {group}" : "新增至 {group]",
+    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "請注意，您只能將可寫通訊錄中的聯絡人添加到聯絡人群組。來自唯讀通訊錄的聯絡人，例如系統通訊錄，無法添加。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "新增至群組",
     "Search {types}" : "搜尋 {types}",
@@ -177,16 +176,16 @@ OC.L10N.register(
     "Unable to get the results" : "無法得到結果",
     "Some members could not be added" : "部分成員無法添加",
     "There was an issue adding members to the team" : "將成員添加到團隊時出現問題",
-    "Team members" : "團隊成員",
     "Loading members list …" : "正在加載成員清單 …",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取會員清單",
-    "Add members" : "添加成員",
     "Add to {circle}" : "添加到 {circle}",
     "Pending" : "待定的",
     "Promote as sole owner" : "晉升作為唯一所有者",
     "Promote to {level}" : "晉升到 {level}",
     "Demote to {level}" : "降級到 {level}",
+    "Are you sure you want to leave this team? This action cannot be undone." : "您確定要離開此團隊嗎？此操作無法復原。",
+    "Leave team failed." : "離開團隊失敗。",
     "Could not delete the member {displayName}" : "不能刪除成員 {displayName}",
     "Could not change the member level to {level}" : "無法將成員級別更改為 {level}",
     "Could not accept membership request" : "無法接受成為成員的申請",
@@ -206,6 +205,7 @@ OC.L10N.register(
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
+    "Add member" : "添加成員",
     "New contact" : "新聯絡人",
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
@@ -246,10 +246,10 @@ OC.L10N.register(
     "Members need to accept invitation" : "會員需要接受邀請",
     "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "會員資格必須由主持人確認/接受（要求「任何人都可以申請會員資格」）",
     "Members can also invite" : "會員也可以邀請",
-    "Visibility" : "可見性",
-    "Visible to everyone" : "所有人都看得到",
-    "Team membership" : "團隊成員身分",
+    "Membership" : "成員資格",
     "Prevent teams from being a member of another team" : "防止團隊成為另一個團隊的成員",
+    "Privacy" : "隱私",
+    "Visible to everyone" : "所有人都看得到",
     "users" : "用戶",
     "Users" : "用戶",
     "groups" : "群組",
@@ -322,6 +322,18 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "團隊中出現錯誤。請檢查主控台以取得更多詳細資訊。",
     "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
-    "Unable to delete contact" : "無法刪除聯絡人"
+    "Unable to delete contact" : "無法刪除聯絡人",
+    "Password protection" : "密碼保護",
+    "Team owned by {owner}" : "{owner} 擁有的團隊",
+    "Team settings" : "團隊設定",
+    "Description" : "描述",
+    "Team resources" : "團隊資源",
+    "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
+    "Settings" : "Settings",
+    "Actions" : "操作",
+    "Team members" : "團隊成員",
+    "Add members" : "添加成員",
+    "Visibility" : "可見性",
+    "Team membership" : "團隊成員身分"
 },
 "nplurals=1; plural=0;");
