@@ -88,31 +88,26 @@ OC.L10N.register(
     "Sort by {sorting}" : "按 {sorting} 排序",
     "Manages" : "管理",
     "Oversees" : "監督",
-    "An error happened during the config change" : "變更設定時發生錯誤",
-    "Password protection" : "密碼保護",
     "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
     "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
     "Unique password …" : "獨一無二的密碼……",
     "Save" : "儲存",
     "Change unique password" : "變更獨一無二的密碼",
     "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
+    "An error happened during the config change" : "變更設定時發生錯誤",
     "There is no description for this team" : "此團隊沒有描述",
     "Enter a description for the team" : "輸入團隊的描述",
     "An error happened during description sync" : "描述同步時發生錯誤",
     "An error happened during name sync" : "名稱同步時發生錯誤",
-    "Team owned by {owner}" : "{owner} 擁有的團隊",
-    "Team settings" : "團隊設定",
+    "Team name" : "團隊名稱",
+    "Team owner" : "團隊擁有者",
+    "Edit" : "編輯",
+    "Cancel" : "取消",
     "Request to join" : "要求加入",
-    "Description" : "描述",
     "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
     "You are not a member of {circle}" : "您不是 {circle} 的成員",
-    "Team resources" : "團隊資源",
-    "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
-    "Team name" : "團隊名稱",
-    "Settings" : "Settings",
-    "Actions" : "動作",
+    "Members" : "成員",
     "Confirm" : "確認",
-    "Cancel" : "取消",
     "Add more info" : "新增更多資訊",
     "More fields" : "更多欄位",
     "Please select a valid format" : "請選取有效格式",
@@ -149,7 +144,6 @@ OC.L10N.register(
     "Go to talk conversation" : "前往對話",
     "View profile" : "檢視個人檔案",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
-    "Edit" : "編輯",
     "Clone contact" : "再製連絡人",
     "Generate QR Code" : "產生 QR Code",
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
@@ -160,8 +154,13 @@ OC.L10N.register(
     "Calendar events with you" : "有您的日曆事件",
     "Deck cards with you" : "有您的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
+    "_Delete {number} contact_::_Delete {number} contacts_" : ["刪除 {number} 個聯絡人"],
+    "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
+    "Are you sure you want to proceed?" : "您想要繼續嗎？",
     "Search contacts …" : "搜尋聯絡人……",
+    "Unselect {number}" : "取消選取 {number}",
     "Add to {group}" : "新增至 {group}",
+    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "請注意，您只能將可寫通訊錄中的聯絡人新增至聯絡人群組。來自唯讀通訊錄（例如系統通訊錄）的聯絡人則無法新增。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "新增至群組",
     "Search {types}" : "搜尋 {types}",
@@ -177,16 +176,16 @@ OC.L10N.register(
     "Unable to get the results" : "無法取得結果",
     "Some members could not be added" : "無法新增部份成員",
     "There was an issue adding members to the team" : "將成員新增至團隊時發生錯誤",
-    "Team members" : "團隊成員",
     "Loading members list …" : "正在載入成員清單……",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取成員清單",
-    "Add members" : "新增成員",
     "Add to {circle}" : "新增至 {circle}",
     "Pending" : "擱置中",
     "Promote as sole owner" : "將其權限升級為唯一擁有者",
     "Promote to {level}" : "將其權限升級為 {level}",
     "Demote to {level}" : "將其權限降級為 {level}",
+    "Are you sure you want to leave this team? This action cannot be undone." : "您確定您想要離開此團隊嗎？此動作無法還原。",
+    "Leave team failed." : "離開團隊失敗。",
     "Could not delete the member {displayName}" : "無法刪除成員 {displayName}",
     "Could not change the member level to {level}" : "無法變更成員等級至 {level}",
     "Could not accept membership request" : "無法接受成員請求",
@@ -201,10 +200,12 @@ OC.L10N.register(
     "Add contact in group" : "新增聯絡人到群組",
     "None" : "無",
     "Select option" : "選取選項",
+    "Personal dates" : "個人日期",
     "Add property of this type" : "新增此類型的屬性",
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
+    "Add member" : "新增成員",
     "New contact" : "新聯絡人",
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
@@ -245,10 +246,10 @@ OC.L10N.register(
     "Members need to accept invitation" : "成員必須接受邀請",
     "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "成員資格必須由主持人確認／接受（必須為「任何人都可以請求成員資格）",
     "Members can also invite" : "成員也可以邀請",
-    "Visibility" : "能見度",
-    "Visible to everyone" : "對所有人可見",
-    "Team membership" : "團隊成員資格",
+    "Membership" : "成員",
     "Prevent teams from being a member of another team" : "避免團隊成為其他團隊的成員",
+    "Privacy" : "隱私權",
+    "Visible to everyone" : "對所有人可見",
     "users" : "使用者",
     "Users" : "使用者",
     "groups" : "群組",
@@ -322,10 +323,17 @@ OC.L10N.register(
     "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成員資格必須由主持人（必須為開放小圈圈）確認／接受",
-    "Manager" : "經理",
-    "Members" : "成員",
-    "Manage members" : "管理成員",
-    "Show team details" : "顯示團隊詳細資訊"
+    "Password protection" : "密碼保護",
+    "Team owned by {owner}" : "{owner} 擁有的團隊",
+    "Team settings" : "團隊設定",
+    "Description" : "描述",
+    "Team resources" : "團隊資源",
+    "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
+    "Settings" : "Settings",
+    "Actions" : "動作",
+    "Team members" : "團隊成員",
+    "Add members" : "新增成員",
+    "Visibility" : "能見度",
+    "Team membership" : "團隊成員資格"
 },
 "nplurals=1; plural=0;");
