@@ -1,24 +1,8 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2020 Matthias Heinisch <nextcloud@matthiasheinisch.de>
- *
- * @author Matthias Heinisch <nextcloud@matthiasheinisch.de>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Contacts\Service\Social;
@@ -82,7 +66,7 @@ class MastodonProvider implements ISocialProvider {
 		try {
 			$result = $this->httpClient->get($profileUrl, ['headers' => ['Accept' => 'application/json']]);
 			$jsonResult = json_decode($result->getBody(), true);
-			return $jsonResult["icon"]["url"] ?? null;
+			return $jsonResult['icon']['url'] ?? null;
 		} catch (\Exception $e) {
 			return null;
 		}
@@ -106,12 +90,12 @@ class MastodonProvider implements ISocialProvider {
 						try {
 							[$masto_user, $masto_server] = $masto_user_server;
 							# search for user webfinger
-							$webfinger = $masto_server . '/.well-known/webfinger?resource=acct:' . $masto_user . '@' . parse_url($masto_server)["host"];
+							$webfinger = $masto_server . '/.well-known/webfinger?resource=acct:' . $masto_user . '@' . parse_url($masto_server)['host'];
 							$result = $this->httpClient->get($webfinger);
 							$jsonResult = json_decode($result->getBody(), null, 512, JSON_THROW_ON_ERROR);
 							# find account link
 							foreach ($jsonResult->links as $link) {
-								if (($link->rel == "self") and ($link->type == "application/activity+json")) {
+								if (($link->rel == 'self') and ($link->type == 'application/activity+json')) {
 									$profileId = $link->href;
 									$profileIds[] = $profileId;
 									break;
@@ -139,7 +123,7 @@ class MastodonProvider implements ISocialProvider {
 		try {
 			$user_server = explode('@', $candidate);
 			if (strpos($candidate, 'http') !== 0) {
-				$masto_server = "https://" . array_pop($user_server);
+				$masto_server = 'https://' . array_pop($user_server);
 				$masto_user = array_pop($user_server);
 			} else {
 				$masto_user = array_pop($user_server);
@@ -150,7 +134,7 @@ class MastodonProvider implements ISocialProvider {
 			}
 			$masto_user = trim($masto_user, '/');
 			$masto_server = trim($masto_server, '/');
-			return array($masto_user, $masto_server);
+			return [$masto_user, $masto_server];
 		} catch (\Exception $e) {
 			return null;
 		}
