@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -15,22 +16,17 @@ use OCP\Settings\ISettings;
 class AdminSettings implements ISettings {
 	protected $appName;
 
-	/** @var IConfig */
-	private $config;
-
-	/** @var IInitialStateService */
-	private $initialStateService;
-
 	/**
 	 * Admin constructor.
 	 *
 	 * @param IConfig $config
 	 * @param IL10N $l
 	 */
-	public function __construct(IConfig $config, IInitialStateService $initialStateService) {
+	public function __construct(
+		private IConfig $config,
+		private IInitialStateService $initialStateService,
+	) {
 		$this->appName = Application::APP_ID;
-		$this->config = $config;
-		$this->initialStateService = $initialStateService;
 	}
 
 	/**
@@ -53,8 +49,8 @@ class AdminSettings implements ISettings {
 
 	/**
 	 * @return int whether the form should be rather on the top or bottom of
-	 * the admin section. The forms are arranged in ascending order of the
-	 * priority values. It is required to return a value between 0 and 100.
+	 *             the admin section. The forms are arranged in ascending order of the
+	 *             priority values. It is required to return a value between 0 and 100.
 	 */
 	public function getPriority() {
 		return 75;
